@@ -6,18 +6,17 @@ my $mw = MainWindow->new;
 
 my $lpe = $mw->LabPopEntry(
    -pattern    => 'alphanum',
-   -label      => 'Alpha-numeric only:',
+   -label      => 'Alpha-numeric only: ',
    -labelPack  => [-side=>'left'],
    
 );
 $lpe->pack;
 
 my $button = $mw->Button(-text=>"Exit", -command=>sub{exit})->pack;
-my $label = $mw->Label(-text=>"Right click somewhere")->pack;
+my $label = $mw->Label(-text=>"Right click in the entry widget")->pack;
 
-# Uncomment either or both of these lines to see their effect
 #$lpe->deleteItem(2,'end');
-#$lpe->addItem(1,["Exit", 'main::exitApp', '<Control-g>', 1]);
+$lpe->addItem(1,["Exit", 'main::exitApp', '<Control-g>', 1]);
 
 MainLoop;
 
